@@ -8,7 +8,7 @@ requires qw( no_index verbose );
 # Load time and dependencies negate execution time
 # use namespace::clean -except => 'meta';
 
-our $VERSION = '0.30';
+our $VERSION = '0.32';
 $VERSION = eval $VERSION;    ## no critic
 
 use English qw( -no_match_vars );    # Avoids reg-ex performance penalty
@@ -71,6 +71,11 @@ sub body_dist {
 	}
 
 	foreach my $module_name (sort keys %{$required_ref}) {
+
+		next
+			if $title eq 'TestRequires'
+			&& $required_ref->{$module_name} =~ m/mcpan/;
+
 		printf "%-*s = %s\n", $pm_length, $module_name,
 			$required_ref->{$module_name};
 	}
@@ -148,7 +153,7 @@ used by L<App::Midgen>
 
 =head1 VERSION
 
-version: 0.30
+version: 0.32
 
 =head1 DESCRIPTION
 
