@@ -8,7 +8,7 @@ requires qw( no_index verbose );
 # Load time and dependencies negate execution time
 # use namespace::clean -except => 'meta';
 
-our $VERSION = '0.30';
+our $VERSION = '0.32';
 $VERSION = eval $VERSION;    ## no critic
 
 use English qw( -no_match_vars );    # Avoids reg-ex performance penalty
@@ -26,8 +26,9 @@ sub header_mi {
 	my $package_name = shift || NONE;
 	my $mi_ver       = shift || NONE;
 
-	print "\nuse inc::Module::Install::DSL "
-		. colored($mi_ver, 'yellow') . ";\n";
+	print "\nuse strict;\n";
+	print "use warnings;\n";
+	print "use inc::Module::Install " . colored($mi_ver, 'yellow') . ";\n";
 
 	if ($package_name ne NONE) {
 		$package_name =~ s{::}{-}g;
@@ -35,8 +36,8 @@ sub header_mi {
 		$package_name =~ tr{-}{/};
 		print "all_from 'lib/$package_name.pm';\n";
 	}
-	print "\n";
 
+	print BRIGHT_BLACK . "license 'perl';" . CLEAR . "\n";
 	return;
 }
 #######
@@ -58,22 +59,32 @@ sub body_mi {
 
 	print "perl_version '$App::Midgen::Min_Version';\n" if $title eq 'RuntimeRequires';
 	print "\n";
-	$title =~ s/^Runtime//;
-	$title =~ s/^TestSuggests/recommends/;
-	$title =~ s/^Test/test_/;
+
+	$title =~ s/^RuntimeRequires/requires/;
+	$title =~ s/^TestRequires/test_requires/;
 
 	foreach my $module_name (sort keys %{$required_ref}) {
 
+		next
+			if $title eq 'test_requires'
+			&& $required_ref->{$module_name} =~ m/mcpan/;
+
 		if ($module_name =~ /^Win32/sxm) {
 			my $sq_key = "'$module_name'";
-			printf "%s %-*s => '%s' %s;\n", lc $title, $pm_length + 2, $sq_key,
+			printf "%s %-*s => '%s' %s;\n", $title, $pm_length + 2, $sq_key,
 				$required_ref->{$module_name}, colored('if win32', 'bright_green');
 		}
 		elsif ($module_name =~ /XS/sxm) {
 			my $sq_key = "'$module_name'";
-			printf "%s %-*s => '%s' %s;\n", lc $title, $pm_length + 2, $sq_key,
+			printf "%s %-*s => '%s' %s;\n", $title, $pm_length + 2, $sq_key,
 				$required_ref->{$module_name}, colored('if can_xs', 'bright_blue');
 		}
+		elsif ($module_name eq 'MRO::Compat') {
+			my $sq_key = "'$module_name'";
+			printf "%s %-*s => '%s' %s;\n", $title, $pm_length + 2, $sq_key,
+				$required_ref->{$module_name},
+				colored('if $] < 5.009005', 'bright_blue');
+		}
 		else {
 			my $sq_key = "'$module_name'";
 			printf "%s %-*s => '%s';\n", lc $title, $pm_length + 2, $sq_key,
@@ -147,7 +158,7 @@ used by L<App::Midgen>
 
 =head1 VERSION
 
-version: 0.30
+version: 0.32
 
 =head1 DESCRIPTION
 
