@@ -8,7 +8,7 @@ requires qw( no_index verbose );
 # Load time and dependencies negate execution time
 # use namespace::clean -except => 'meta';
 
-our $VERSION = '0.30';
+our $VERSION = '0.32';
 $VERSION = eval $VERSION;    ## no critic
 
 use English qw( -no_match_vars );    # Avoids reg-ex performance penalty
@@ -26,15 +26,17 @@ sub header_dsl {
 	my $mi_ver       = shift || NONE; # defined shift ? shift : NONE - don't work as per perl5100delta.pod
 
 	$package_name =~ s{::}{/}g;
-
-	print "\nuse inc::Module::Install::DSL "
+	print "\nuse strict;\n";
+	print "use warnings;\n";
+	print "use inc::Module::Install::DSL "
 		. colored($mi_ver, 'yellow') . ";\n";
 	if ($package_name ne NONE) {
 		print "all_from lib/$package_name.pm\n";
 		print "requires_from lib/$package_name.pm\n";
 	}
 
-	print "\n";
+	print BRIGHT_BLACK . "license perl" . CLEAR . "\n";
+
 	return;
 }
 #######
@@ -57,21 +59,29 @@ sub body_dsl {
 			$pm_length = length $module_name;
 		}
 	}
-	$title =~ s/^Runtime//;
-	$title =~ s/^TestSuggests/recommends/;
-	$title =~ s/^Test/test_/;
+
+	$title =~ s/^RuntimeRequires/requires/;
+	$title =~ s/^TestRequires/test_requires/;
 
 	foreach my $module_name (sort keys %{$required_ref}) {
 
+		next
+			if $title eq 'test_requires'
+			&& $required_ref->{$module_name} =~ m/mcpan/;
+
 		if ($module_name =~ /^Win32/sxm) {
-			printf "%s %-*s %s %s\n", lc $title, $pm_length, $module_name,
+			printf "%s %-*s %s %s\n", $title, $pm_length, $module_name,
 				$required_ref->{$module_name}, colored('if win32', 'bright_green');
 		}
 		elsif ($module_name =~ /XS/sxm) {
-			printf "%s %-*s %s %s\n", lc $title, $pm_length, $module_name,
+			printf "%s %-*s %s %s\n", $title, $pm_length, $module_name,
 				$required_ref->{$module_name}, colored('if can_xs', 'bright_blue');
 		}
-
+		elsif ($module_name eq 'MRO::Compat') {
+			printf "%s %-*s %s %s\n", $title, $pm_length, $module_name,
+				$required_ref->{$module_name},
+				colored('if $] < 5.009005', 'bright_blue');
+		}
 		else {
 			printf "%s %-*s %s\n", lc $title, $pm_length, $module_name,
 				$required_ref->{$module_name};
@@ -130,7 +140,7 @@ used by L<App::Midgen>
 
 =head1 VERSION
 
-version: 0.30
+version: 0.32
 
 =head1 DESCRIPTION
 
