@@ -3,19 +3,21 @@ package App::Midgen::Role::UseOk;
 use constant {BLANK => q{ }, NONE => q{}, TWO => 2, THREE => 3,};
 
 use Moo::Role;
-requires qw( ppi_document debug format xtest _process_found_modules develop meta2 );
+requires
+	qw( ppi_document debug verbose format xtest _process_found_modules develop meta2 );
 
 # Load time and dependencies negate execution time
 # use namespace::clean -except => 'meta';
 
-our $VERSION = '0.30';
-$VERSION = eval $VERSION; ## no critic
+our $VERSION = '0.32';
+$VERSION = eval $VERSION;    ## no critic
 
 use PPI;
 use Try::Tiny;
-use Data::Printer {caller_info => 1, colored => 1,};
+use Data::Printer {caller_info => 1,};
 use Tie::Static qw(static);
 
+#use List::MoreUtils qw( lastidx );
 
 #######
 # composed method - _xtests_in_single_quote
@@ -23,6 +25,8 @@ use Tie::Static qw(static);
 sub xtests_use_ok {
 	my $self = shift;
 	my $phase_relationship = shift || NONE;
+	my @modules;
+	my @version_strings;
 
 	#PPI::Document
 	#  PPI::Statement::Scheduled
@@ -41,8 +45,6 @@ sub xtests_use_ok {
 	#            PPI::Token::Whitespace  	' '
 	#            PPI::Token::Quote::Single  	''2.30''
 
-	my @modules;
-	my @version_strings;
 	my @chunks =
 
 		map  { [$_->schildren] }
@@ -70,7 +72,7 @@ sub xtests_use_ok {
 										foreach my $element (@{$ppi_se->{children}}) {
 
 											# some fudge to remember the module name if falied
-											static \ my $previous_module;
+											static \my $previous_module;
 											if ( $element->isa('PPI::Token::Quote::Single')
 												|| $element->isa('PPI::Token::Quote::Double'))
 											{
@@ -80,8 +82,9 @@ sub xtests_use_ok {
 												$module =~ s/['|"]$//;
 												if ($module =~ m/\A[A-Z]/) {
 
-													warn 'found module - ' . $module if $self->debug;
+													print "found module - $module\n" if $self->debug;
 													push @modules, $module;
+													$version_strings[$#modules] = undef;
 													$previous_module = $module;
 												}
 											}
@@ -98,18 +101,22 @@ sub xtests_use_ok {
 												$version_string =~ s/['|"]$//;
 												next if $version_string !~ m/\A[\d|v]/;
 
-												$version_string = version::is_lax($version_string) ? $version_string : 0;
+												$version_string
+													= version::is_lax($version_string)
+													? $version_string
+													: 0;
 
-												warn 'found version_string - ' . $version_string
+												print "found version_string - $version_string\n"
 													if $self->debug;
 												try {
-													$self->{found_version}{$previous_module}
-														= $version_string
-														if $previous_module;
+													if ($previous_module) {
+														$self->{found_version}{$previous_module}
+															= $version_string;
+														$version_strings[$#modules] = $version_string;
+													}
 
 													$previous_module = undef;
 												};
-
 											}
 										}
 									}
@@ -122,15 +129,21 @@ sub xtests_use_ok {
 		}
 	}
 
+	@version_strings = map { defined $_ ? $_ : 0 } @version_strings;
+	p @modules         if $self->debug;
+	p @version_strings if $self->debug;
 
-	# if we found a module, process it with the correct catogery
 	if (scalar @modules > 0) {
 
-		if ($self->xtest) {
-			$self->_process_found_modules('DevelopRequires', \@modules, __PACKAGE__ );
-		}
-		else {
-			$self->_process_found_modules('TestRequires', \@modules, __PACKAGE__ );
+		for (0 .. $#modules) {
+			print "Info: UseOk -> Sending $modules[$_] - $version_strings[$_]\n"
+				if ($self->verbose == TWO);
+			try {
+				$self->_process_found_modules(
+					$phase_relationship, $modules[$_], $version_strings[$_],
+					__PACKAGE__,         $phase_relationship,
+				);
+			};
 		}
 	}
 	return;
@@ -153,7 +166,7 @@ for methods in use_ok in BEGIN blocks, used by L<App::Midgen>
 
 =head1 VERSION
 
-version: 0.30
+version: 0.32
 
 =head1 METHODS
 
